# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test_56
# FileName:      requests_method.py
# Author:       xxxxxxx
# Datetime:     2023/8/4 15:42
# Description:
# 
# ---------------------------------------------------------------------------
import base64
import requests

from pytest框架.common.read_ini import ReadIni


class RequestsMethod:
    def __init__(self):
        """
        关联登录成功的状态，关联token
        """
        # 配置登录的url
        url = ReadIni().get_host("test_bpm") + "/auth"
        # 配置登录数据
        data = {"username": "admin", "password": base64.b64encode("123456".encode("utf-8")).decode("utf-8")}
        # 创建Session对象
        self.bpm_session = requests.sessions.Session()
        # 发送请求，获取token，将token更新到Session对象的headers
        self.bpm_session.headers["Authorization"] = "Bearer " + self.bpm_session.post(url=url, json=data).json().get("token")

    def request_all(self, method, url, mime, case_data):
        """
        根据不同的媒体类型，使用不同的关键字传参
        :param method: 请求方法
        :param url: url
        :param mime: 媒体类型
        :param case_data: 用例数据
        :return: Response type
        """
        # 判断媒体类型的值是否表单的媒体类型，如果是，使用data关键字传参
        if mime == "application/x-www-form-urlencoded" or mime == "x-www-form-urlencoded":
            return self.bpm_session.request(method=method, url=url, data=case_data)
        # 判断媒体类型的值是否json的媒体类型，如果是，使用json关键字传参
        elif mime == "application/json" or mime == "json":
            return self.bpm_session.request(method=method, url=url, json=case_data)
        # 判断媒体类型的值是否multipart/form-data的媒体类型，如果是，使用files关键字传参
        elif mime == "multipart/form-data" or mime == "form-data":
            return self.bpm_session.request(method=method, url=url, files=case_data)
        # 判断媒体类型的值是否query或者为params的媒体类型，如果是，使用params关键字传参
        elif mime == "query" or mime == "params":
            return self.bpm_session.request(method=method, url=url, params=case_data)

        # 判断媒体类型的值是否text/plain或者为text的媒体类型，如果是，使用data关键字传参
        elif mime == "text/plain" or mime == "text":
            return self.bpm_session.request(method=method, url=url, data=case_data)

        # 判断媒体类型的值是否为application/Json|query或者json|query，如果是，表示地址栏和请求体同时传参
        elif mime == "application/Json|query" or mime == "json|query" or "json|params":
            return self.bpm_session.request(method=method, url=url, params=case_data["query"], json=case_data["body"])

        # 判断媒体类型的值是否None，如果是，表示没有传参
        elif mime is None:
            return self.bpm_session.request(method=method, url=url)

        else:
            raise NameError("媒体类型的值错误")


if __name__ == '__main__':
    req = RequestsMethod()
